@@ -1,4 +1,4 @@
-#[derive(Debug)]
+#[derive(Debug, Clone, Copy)]
 pub enum SetGroupSettingValue {
     Maintain,
     Decrease,
@@ -9,7 +9,7 @@ pub enum SetGroupSettingValue {
     SetTargetSetpoint(u8),
 }
 
-#[derive(Debug)]
+#[derive(Debug, Clone, Copy)]
 pub enum SetGroupControlMethod {
     Maintain,
     Toggle,
@@ -17,7 +17,7 @@ pub enum SetGroupControlMethod {
     Temperature,
 }
 
-#[derive(Debug)]
+#[derive(Debug, Clone, Copy)]
 pub enum SetGroupPower {
     Maintain,
     ChangeToNextState,
@@ -26,20 +26,20 @@ pub enum SetGroupPower {
     SetTurbo,
 }
 
-#[derive(Debug)]
+#[derive(Debug, PartialEq, Clone, Copy)]
 pub enum GroupPowerState {
     Off,
     On,
     Turbo,
 }
 
-#[derive(Debug)]
+#[derive(Debug, PartialEq, Clone, Copy)]
 pub enum GroupControlMethod {
     Temperature,
     Percentage,
 }
 
-#[derive(Debug)]
+#[derive(Debug, Clone, Copy)]
 pub enum SetACPowerState {
     Maintain,
     Toggle,
@@ -47,8 +47,9 @@ pub enum SetACPowerState {
     On,
 }
 
-#[derive(Debug)]
-pub enum ACMode {
+#[derive(Debug, Clone, Copy)]
+pub enum SetACMode {
+    Maintain,
     Auto,
     Heat,
     Dry,
@@ -56,7 +57,18 @@ pub enum ACMode {
     Cool,
 }
 
-#[derive(Debug)]
+#[derive(Debug, PartialEq, Clone, Copy)]
+pub enum ACMode {
+    Auto,
+    Heat,
+    Dry,
+    Fan,
+    Cool,
+    AutoHeat,
+    AutoCool,
+}
+
+#[derive(Debug, PartialEq, Clone, Copy)]
 pub enum ACFanSpeed {
     Auto,
     Quiet,
@@ -67,7 +79,7 @@ pub enum ACFanSpeed {
     Turbo,
 }
 
-#[derive(Debug)]
+#[derive(Debug, Clone, Copy)]
 pub enum SetACSetpoint {
     Maintain,
     Value(u8),
@@ -77,7 +89,7 @@ pub enum SetACSetpoint {
     Increase,
 }
 
-#[derive(Debug)]
+#[derive(Debug, PartialEq, Clone, Copy)]
 pub enum ACPowerState {
     Off,
     On,
